<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');

// Verificar se é uma solicitação para obter logs da Xtracky
if (isset($_GET['get_xtracky_logs']) && $_GET['get_xtracky_logs'] === 'true') {
    $paymentId = $_GET['id'] ?? '';
    if (empty($paymentId)) {
        echo json_encode(['error' => 'ID não fornecido']);
        exit;
    }
    
    // Função para obter logs de webhook relacionados à Xtracky
    $logs = getXtrackyLogs($paymentId);
    echo json_encode([
        'success' => true,
        'xtracky_logs' => $logs
    ]);
    exit;
}

if (!isset($_GET['id'])) {
    echo json_encode(['error' => 'ID não fornecido']);
    exit;
}

$id = $_GET['id'];

// Remove qualquer caractere especial ou espaço do ID
$id = trim($id);
$id = preg_replace('/[^a-zA-Z0-9\-]/', '', $id);

try {
    // Conecta ao SQLite
    $dbPath = __DIR__ . '/database.sqlite';
    $db = new PDO("sqlite:$dbPath");
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Busca o status do pagamento
    $stmt = $db->prepare("SELECT * FROM pedidos WHERE transaction_id = :transaction_id");
    $stmt->execute(['transaction_id' => $id]);
    $pedido = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$pedido) {
        echo json_encode([
            'success' => false,
            'status' => 'error',
            'message' => 'Pedido não encontrado'
        ]);
        exit;
    }

    echo json_encode([
        'success' => true,
        'status' => $pedido['status'],
        'transaction_id' => $pedido['transaction_id'],
        'data' => [
            'amount' => $pedido['valor'],
            'created_at' => $pedido['created_at'],
            'updated_at' => $pedido['updated_at'],
            'customer' => [
                'name' => $pedido['nome'],
                'email' => $pedido['email'],
                'document' => $pedido['cpf']
            ]
        ]
    ]);

} catch (Exception $e) {
    error_log("[Verificar] ❌ Erro: " . $e->getMessage());
    echo json_encode([
        'success' => false,
        'status' => 'error',
        'message' => 'Erro ao verificar o status do pagamento'
    ]);
} 

// Função para obter logs relacionados à Xtracky a partir do log de erro do PHP
function getXtrackyLogs($paymentId) {
    $logFile = ini_get('error_log');
    if (!file_exists($logFile) || !is_readable($logFile)) {
        return ['Arquivo de log não encontrado ou não legível'];
    }
    
    $logs = [];
    $lines = file($logFile);
    
    // Filtrar apenas as linhas relacionadas à Xtracky e ao ID da transação
    foreach ($lines as $line) {
        if (strpos($line, 'XTRACKY') !== false && strpos($line, $paymentId) !== false) {
            $logs[] = $line;
        }
    }
    
    // Se não encontrou logs específicos, retornar mensagem informativa
    if (empty($logs)) {
        // Busca logs gerais do webhook para esse ID
        foreach ($lines as $line) {
            if (strpos($line, '[Webhook]') !== false && strpos($line, $paymentId) !== false) {
                $logs[] = $line;
            }
        }
        
        if (empty($logs)) {
            return ['Nenhum log encontrado para essa transação'];
        }
    }
    
    // Limitar a quantidade de logs retornados
    return array_slice($logs, -20);
} 