<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');

if (!isset($_GET['id'])) {
    echo json_encode(['error' => 'ID não fornecido']);
    exit;
}

$id = $_GET['id'];
$secretKey = '0db05e84-77cc-40a0-afd8-c1ca035666be';
$apiUrl = 'https://app.nivopaybr.com/api/v1';

// Remove qualquer caractere especial ou espaço do ID
$id = trim($id);
$id = preg_replace('/[^a-zA-Z0-9\-]/', '', $id);

// Log da requisição
error_log("[Nivopay] 🔍 Iniciando verificação para ID: " . $id);

// Configura a URL com o ID como query parameter
$url = $apiUrl . '/transaction.getPayment?id=' . urlencode($id);
error_log("[Nivopay] 🌐 URL da requisição: " . $url);

// Configuração do cURL para verificar o status do pagamento
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
curl_setopt($ch, CURLOPT_HTTPGET, true); // Garante que é um GET
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Authorization: ' . $secretKey,
    'Content-Type: application/json',
    'Accept: application/json'
]);

// Adiciona opções para debug
curl_setopt($ch, CURLOPT_VERBOSE, true);
$verbose = fopen('php://temp', 'w+');
curl_setopt($ch, CURLOPT_STDERR, $verbose);

// Log dos headers enviados
$headers = [];
curl_setopt($ch, CURLOPT_HEADERFUNCTION,
    function($curl, $header) use (&$headers) {
        $len = strlen($header);
        $header = explode(':', $header, 2);
        if (count($header) < 2) // ignore invalid headers
            return $len;

        $headers[strtolower(trim($header[0]))][] = trim($header[1]);
        return $len;
    }
);

$response = curl_exec($ch);
$httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
$curlError = curl_error($ch);
$curlErrno = curl_errno($ch);

// Log detalhado do cURL
rewind($verbose);
$verboseLog = stream_get_contents($verbose);
error_log("[Nivopay] 🔍 Detalhes da requisição cURL:\n" . $verboseLog);
error_log("[Nivopay] 📨 Headers enviados: " . print_r($headers, true));
error_log("[Nivopay] 🔑 Authorization header: " . $secretKey);
error_log("[Nivopay] 🔍 URL completa: " . $url);

if ($curlError) {
    error_log("[Nivopay] ❌ Erro cURL: " . $curlError . " (errno: " . $curlErrno . ")");
}

curl_close($ch);

error_log("[Nivopay] 📊 HTTP Status Code: " . $httpCode);
error_log("[Nivopay] 📄 Resposta bruta: " . $response);

if ($httpCode === 200) {
    $result = json_decode($response, true);
    $jsonError = json_last_error();
    
    if ($jsonError !== JSON_ERROR_NONE) {
        error_log("[Nivopay] ❌ Erro ao decodificar JSON: " . json_last_error_msg());
        echo json_encode([
            'status' => 'error',
            'message' => 'Erro ao processar resposta da API',
            'error' => json_last_error_msg()
        ]);
        exit;
    }
    
    error_log("[Nivopay] ✅ Resposta decodificada: " . print_r($result, true));
    error_log("[Nivopay] 📊 Status do pagamento: " . ($result['status'] ?? 'undefined'));

    // Se o pagamento foi aprovado, envia para utmify.php
    if ($result['status'] === 'PAID' || $result['status'] === 'APPROVED') {
        error_log("[Sistema] 📡 Pagamento aprovado, enviando dados para utmify.php");

        $utmifyData = [
            'orderId' => $result['id'],
            'platform' => 'MinhaPlataforma',
            'paymentMethod' => 'pix',
            'status' => 'approved',
            'createdAt' => date('Y-m-d H:i:s'),
            'approvedDate' => date('Y-m-d H:i:s'),
            'refundedAt' => null,
            'customer' => [
                'name' => $result['customer']['name'] ?? '',
                'email' => $result['customer']['email'] ?? '',
                'phone' => $result['customer']['phone'] ?? null,
                'document' => $result['customer']['document'] ?? '',
                'country' => 'BR',
                'ip' => $_SERVER['REMOTE_ADDR'] ?? null
            ],
            'products' => [
                [
                    'id' => uniqid('PROD_'),
                    'name' => 'Liberação de Benefício',
                    'planId' => null,
                    'planName' => null,
                    'quantity' => 1,
                    'priceInCents' => $result['amount'] ?? 6190
                ]
            ],
            'trackingParameters' => [
                'utm_source' => $_GET['utm_source'] ?? null,
                'utm_medium' => $_GET['utm_medium'] ?? null,
                'utm_campaign' => $_GET['utm_campaign'] ?? null,
                'utm_content' => $_GET['utm_content'] ?? null,
                'utm_term' => $_GET['utm_term'] ?? null
            ],
            'commission' => [
                'totalPriceInCents' => $result['amount'] ?? 6190,
                'gatewayFeeInCents' => $result['fee']['fixedAmount'] ?? 0,
                'userCommissionInCents' => $result['amount'] ?? 6190
            ],
            'isTest' => false
        ];

        // Usando URL relativa ao servidor web
        $serverUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]";
        $utmifyUrl = $serverUrl . "/gov/checkout/utmify.php";
        
        error_log("[Sistema] 📦 Enviando dados para utmify.php: " . json_encode($utmifyData));
        error_log("[Sistema] �� URL do utmify.php: " . $utmifyUrl);

        $ch = curl_init($utmifyUrl);
        curl_setopt_array($ch, [
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POST => true,
            CURLOPT_POSTFIELDS => json_encode($utmifyData),
            CURLOPT_HTTPHEADER => ['Content-Type: application/json'],
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_SSL_VERIFYHOST => false
        ]);

        $utmifyResponse = curl_exec($ch);
        $utmifyHttpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        
        error_log("[Sistema] ✉️ Resposta do utmify.php: " . $utmifyResponse);
        error_log("[Sistema] 📊 Status code do utmify.php: " . $utmifyHttpCode);

        curl_close($ch);
    }
    
    echo json_encode([
        'success' => true,
        'status' => $result['status'] ?? 'PENDING',
        'transaction_id' => $result['id'] ?? null,
        'data' => $result
    ]);
} else {
    $errorDetails = [
        'httpCode' => $httpCode,
        'response' => $response,
        'curlError' => $curlError,
        'curlErrno' => $curlErrno,
        'url' => $url,
        'headers' => $headers
    ];
    
    error_log("[Nivopay] ❌ Erro ao verificar pagamento: " . print_r($errorDetails, true));
    
    echo json_encode([
        'success' => false,
        'status' => 'error',
        'message' => 'Erro ao verificar o status do pagamento',
        'error' => $errorDetails
    ]);
} 